document.addEventListener('DOMContentLoaded', () => {
  const messageContainer = document.getElementById('messageContainer');
  const userInput = document.getElementById('userInput');
  const sendButton = document.getElementById('sendButton');
  const themeToggle = document.querySelector('.theme-toggle');
  
  // Theme handling
  let isDark = window.matchMedia('(prefers-color-scheme: dark)').matches;
  updateTheme();
  
  themeToggle.addEventListener('click', () => {
    isDark = !isDark;
    updateTheme();
  });
  
  function updateTheme() {
    document.documentElement.setAttribute('data-theme', isDark ? 'dark' : 'light');
    themeToggle.textContent = isDark ? '☀️' : '🌙';
  }
  
  // Auto-resize textarea
  userInput.addEventListener('input', () => {
    userInput.style.height = 'auto';
    userInput.style.height = userInput.scrollHeight + 'px';
  });
  
  // Send message handling
  function sendMessage() {
    const message = userInput.value.trim();
    if (!message) return;
    
    // Add user message
    addMessage(message, 'user');
    userInput.value = '';
    userInput.style.height = 'auto';
    
    // Simulate AI response
    setTimeout(() => {
      const responses = [
        "That's an interesting perspective. Can you tell me more?",
        "I understand what you're saying. Let me think about that.",
        "Thank you for sharing. Here's what I think...",
        "That's a great point! Have you considered...",
      ];
      const randomResponse = responses[Math.floor(Math.random() * responses.length)];
      addMessage(randomResponse, 'ai');
    }, 1000);
  }
  
  function addMessage(content, sender) {
    const messageDiv = document.createElement('div');
    messageDiv.className = `message ${sender}`;
    
    const avatar = document.createElement('div');
    avatar.className = 'avatar';
    avatar.textContent = sender.toUpperCase();
    
    const contentDiv = document.createElement('div');
    contentDiv.className = 'content';
    contentDiv.textContent = content;
    
    messageDiv.appendChild(avatar);
    messageDiv.appendChild(contentDiv);
    messageContainer.appendChild(messageDiv);
    
    // Scroll to bottom
    messageContainer.scrollTop = messageContainer.scrollHeight;
  }
  
  // Event listeners
  sendButton.addEventListener('click', sendMessage);
  
  userInput.addEventListener('keypress', (e) => {
    if (e.key === 'Enter' && !e.shiftKey) {
      e.preventDefault();
      sendMessage();
    }
  });
});